@@ -184,9 +184,15 @@ switch ((completed.alg).type){
                 if(((completed.alg).fi_base1==1)&&((completed.alg).fi_natural==1)) gtk_label_set_text (GTK_LABEL(label_ss3),"Functional Iteration(natural,basic,x(0)=I)");
                 if(((completed.alg).fi_base1==1)&&((completed.alg).fi_traditional==1)) gtk_label_set_text (GTK_LABEL(label_ss3),"Functional Iteration(traditional,basic,x(0)=I)");
                 if(((completed.alg).fi_base1==1)&&((completed.alg).fi_Ubased==1)) gtk_label_set_text (GTK_LABEL(label_ss3),"Functional Iteration(U-based,basic,x(0)=I)");
+                if(((completed.alg).fi_base_u==1)&&((completed.alg).fi_natural==1)) gtk_label_set_text (GTK_LABEL(label_ss3),"Functional Iteration(natural,basic,x user)");
+                if(((completed.alg).fi_base_u==1)&&((completed.alg).fi_traditional==1)) gtk_label_set_text (GTK_LABEL(label_ss3),"Functional Iteration(traditional,basic,x user)");
+                if(((completed.alg).fi_base_u==1)&&((completed.alg).fi_Ubased==1)) gtk_label_set_text (GTK_LABEL(label_ss3),"Functional Iteration(U-based,basic,x user)");
                 if(((completed.alg).fi_shift==1)&&((completed.alg).fi_natural==1)) gtk_label_set_text (GTK_LABEL(label_ss3),"Functional Iteration(natural,shift)");
                 if(((completed.alg).fi_shift==1)&&((completed.alg).fi_traditional==1)) gtk_label_set_text (GTK_LABEL(label_ss3),"Functional Iteration(traditional,shift)");
                 if(((completed.alg).fi_shift==1)&&((completed.alg).fi_Ubased==1)) gtk_label_set_text (GTK_LABEL(label_ss3),"Functional Iteration(U-based,shift)");
+                if(((completed.alg).fi_shift_u==1)&&((completed.alg).fi_natural==1)) gtk_label_set_text (GTK_LABEL(label_ss3),"Functional Iteration(natural,shift, x user)");
+                if(((completed.alg).fi_shift_u==1)&&((completed.alg).fi_traditional==1)) gtk_label_set_text (GTK_LABEL(label_ss3),"Functional Iteration(traditional,shift, x user)");
+                if(((completed.alg).fi_shift_u==1)&&((completed.alg).fi_Ubased==1)) gtk_label_set_text (GTK_LABEL(label_ss3),"Functional Iteration(U-based,shift, x user)");
 
                 break;
         case 4: if( (completed.alg).is_base==1) gtk_label_set_text (GTK_LABEL(label_ss3),"Invariant Subspace(basic)");
